/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file save.h
 *
 * @type subsystem
 *
 * @description
 *
 * The save subsystem creates and handles RISC OS Style Guide compliant
 * save boxes, including the extensions to handle options on the save box.
 */

#ifndef __rov_save
#define __rov_save


#ifdef __cplusplus
extern "C"
{
#endif

#ifndef __rov_main
#include "main.h"
#endif

/**
 * Definition of a save handler.
 * @param name the file name to save.
 * @return non-zero for successful save (and close box).
 * @note Called when the filename is entered, or when the file is dropped
 * onto the filer window (or application), and the response is sent back.
 */
typedef int (* _rov_save)(char *name);

/**
 * Definition of a selection handler.
 * @param index the index of the option selected.
 */
typedef void (* _rov_select)(int index);

typedef struct {
  int options;
  _rov_select option_change;
  char *option[1];
} saveas_list;

typedef struct {
  unsigned char expand;
  char data[11];
} saveas_valid;

#ifdef OLD_SAVEAS
canvas saveas(char * , int, int, _rov_save, saveas_list *); /* Saveas (name, type, size, rtne, opts)	 */
canvas saveas_sticky(char * , int, int, _rov_save, saveas_list *);
 							/* Sticky saveas (as saveas)	 */
#else
/**
 * Create a save box as a menu.
 * @param name the current name of the file.
 * @param type the current file type.
 * @param size the current size.
 * @param handler the save handler.
 * @param options the number of options after the list.
 * @param ... a sequence of strings  for the options. Note that the first
 * character is the depth of options, with zero being a check box, and
 * non-zero being a radio icon.
 * @return the canvas generated.
 * @see saveas_sticky()
 */
canvas saveas(char *name,
	      int type,
	      int size,
	      _rov_save handler,
	      int options,
	      ...);
 		
/**
 * Create a save box as a canvas which does not close if he user
 * clicks outside the box.
 * @param name the current name of the file.
 * @param type the current file type.
 * @param size the current size.
 * @param handler the save handler.
 * @param options the number of options after the list.
 * @param ... a sequence of strings  for the options. Note that the first
 * character is the depth of options, with zero being a check box, and
 * non-zero being a radio icon.
 * @return the canvas generated.
 * @see saveas()
 */
canvas saveas_sticky(char *name,
		     int type,
		     int size,
		     _rov_save handler,
		     int options,
		     ...);
#endif

/**
 * Find out if the saved file is 'safe' (ie. not
 * stored in memory).
 * @return non-zero for safe.
 */
int saveas_issafe(void);

/**
 * Change the file type for the save file.
 * @param type the new file type,
 */
void saveas_changefiletype(int type);

/**
 * Get the state of an option.
 * @param index the option index.
 * @return non-zero if the option is selected.
 */
int saveas_getoptionstate(int index);

/**
 * Set the state of an option.
 * @param index the option index.
 * @param selected non-zero to select, zero for unselected.
 */
void saveas_setoptionstate(int index, 
			   int selected);

/**
 * Fade/unfade an option.
 * @param index the option index.
 * @param faded non-zero to fade, zero for unfaded.
 */
void saveas_fadeoption(int index,
		       int faded);

/**
 * Make the save box 3D.
 * @note This has been deprecated, as the 3D status is checked
 * when the saveas box is created.
 */
void saveas_make3d(void);

/**
 * Change the filename.
 * @param name the new filename.
 */
void saveas_changefilename(char *name);

/**
 * Close the save box.
 * @note This is normally used for saveas_stick().
 * @see saveas_sticky()
 */
void saveas_closedown(void);

/**
 * The text for "Save" to change for internationalisation.
 */
extern char saveas_savetxt[];

/**
 * The text for "Cancel" to change for internationalisation.
 */
extern char saveas_canceltxt[];

/**
 * The pointer to the file name buffer.
 */
extern char saveas_filename[];

/**
 * The pointer to the sprite name buffer.
 */
extern char saveas_spritename[];


#ifdef __cplusplus
}
#endif

#endif
